package imagefilters

/**
 * This class implements the various image filters
 */
object ImageFilters {
  def filter(src: Array[Array[Int]], func: (Int, Int, Int) => Int): Array[Array[Int]] = {
    val height: Int = src.length
    val width: Int = if (height == 0) 0 else src(0).length
    val dst: Array[Array[Int]] = Array.ofDim(height, width)
    for (y: Int <- 0 until height) {
      for (x: Int <- 0 until width) {
        dst(y)(x) = func(src(y)(x), x, y)
      }
    }
    return dst
  }

  def duplicate(a: Array[Array[Int]]): Array[Array[Int]] = filter(a, (value, x, y) => value)
  def threshold(a: Array[Array[Int]], thresh: Int): Array[Array[Int]] = filter(a, (value, x, y) => if (value > thresh) 255 else 0)
}
